summaryrefslogtreecommitdiff
path: root/src/mongo/db/catalog/coll_mod.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/catalog/coll_mod.cpp')
-rw-r--r--src/mongo/db/catalog/coll_mod.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mongo/db/catalog/coll_mod.cpp b/src/mongo/db/catalog/coll_mod.cpp
index 52653d1c0d1..69c72434180 100644
--- a/src/mongo/db/catalog/coll_mod.cpp
+++ b/src/mongo/db/catalog/coll_mod.cpp
@@ -234,13 +234,13 @@ StatusWith<CollModRequest> parseCollModRequest(OperationContext* opCtx,
}
} else if (fieldName == "validator" && !isView) {
// If the feature compatibility version is not kLatest, and we are validating features
// as master, ban the use of new agg features introduced in kLatest to prevent them from
// being persisted in the catalog.
boost::optional<ServerGlobalParams::FeatureCompatibility::Version>
maxFeatureCompatibilityVersion;
// (Generic FCV reference): This FCV check should exist across LTS binary versions.
ServerGlobalParams::FeatureCompatibility::Version fcv;
- if (serverGlobalParams.validateFeaturesAsMaster.load() &&
+ if (serverGlobalParams.validateFeaturesAsPrimary.load() &&
serverGlobalParams.featureCompatibility.isLessThan(
ServerGlobalParams::FeatureCompatibility::kLatest, &fcv)) {
maxFeatureCompatibilityVersion = fcv;
@@ -234,13 +234,13 @@ StatusWith<CollModRequest> parseCollModRequest(OperationContext* opCtx,
} else if (fieldName == "validator" && !isView) {
// If the feature compatibility version is not kLatest, and we are validating features
- // as master, ban the use of new agg features introduced in kLatest to prevent them from
- // being persisted in the catalog.
+ // as primary, ban the use of new agg features introduced in kLatest to prevent them
+ // from being persisted in the catalog.
boost::optional<ServerGlobalParams::FeatureCompatibility::Version>
maxFeatureCompatibilityVersion;